@@ -2,7 +2,7 @@ from googletrans import Translator
 import requests
 
 def chat(value):
-    if("sahibin kim" in value.lowercase()):
+    if("sahibin kim" in value.lower()):
         print("kenan")
         return "Sahibim namıdeğer r4isy."
     else:
@@ -11,10 +11,10 @@ def chat(value):
         response = requests.get("http://api.brainshop.ai/get?bid=153868&key=rcKonOgrUFmn5usX&uid=1&msg=" + t.text)
         veri = response.text.split(':"')[-1].split('"}')[0]
         translated = translator.translate(veri, dest="tr")
-        if("zackybot" in translated.text.lowercase()):
+        if("zackybot" in translated.text.lower()):
             new_string = "Adım, kenu-ai. r4isy tarafından yazıldım."
             return new_string
-        elif("acobot.ai" in translated.text.lowercase() or "acobot" in translated.text.lowercase()):
+        elif("acobot.ai" in translated.text.lower() or "acobot" in translated.text.lower()):
             new_string = "Adım kenu-ai. r4isy tarafından yazıldım."
             return new_string
         else:
